from typing import Any, Literal

from pydantic import AnyHttpUrl, BaseModel, ConfigDict, computed_field


def credential_schema(schema: dict[str, Any]) -> None:
    """
    Credential model schema adjustment.

    A simple function to remove the attributes that shouldn't be part of the UI schema
    from the schema itself.
    """
    for attr in ('prefix', 'name', 'slug', 'definition', 'description'):
        schema.get('properties', {}).pop(attr, None)


class Credential(BaseModel):
    """
    Credential base class
    """

    model_config = ConfigDict(json_schema_extra=credential_schema)
    description: str
    prefix: str
    name: str
    slug: str

    @computed_field
    @property
    def definition(self) -> dict[str, Any]:
        return self.model_json_schema()


class TenableVMCredential(Credential):
    """
    Tenable Vulnerability Management Credential
    """

    prefix: Literal['tio'] = 'tio'
    name: Literal['Tenable Vulnerability Management'] = (
        'Tenable Vulnerability Management'
    )
    slug: Literal['tvm'] = 'tvm'
    description: str = 'Tenable Vulnerability Management Credential'
    url: AnyHttpUrl = 'https://cloud.tenable.com'
    access_key: str
    secret_key: str


class TenableSCCredential(Credential):
    """
    Tenable Security Center Credential
    """

    prefix: Literal['tio'] = 'tsc'
    name: Literal['Tenable Security Center'] = 'Tenable Security Center'
    slug: Literal['tvm'] = 'tsc'
    description: str = 'Tenable Security Center Credential'
    url: AnyHttpUrl
    access_key: str
    secret_key: str



import logging

from pydantic import AnyHttpUrl

from tenint import Connector, Credential, Settings


class TestCredential(Credential):
    prefix: str = 'test'
    name: str = 'Test Credential'
    slug: str = 'test'
    api_key: str
    url: AnyHttpUrl = 'https://httpbin.org/get'


class AppSettings(Settings):
    is_bool: bool = True


log = logging.getLogger('test-connector')
connector = Connector(settings=AppSettings, credentials=[TestCredential])


@connector.job
def main(config: AppSettings):
    log.debug('This is a debug test')
    log.info('this is an info test')
    log.warning('this is a warning')
    log.error('this is an error')
    print('hello world')


if __name__ == '__main__':
    connector.app()
